﻿using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Data;
using System.Dynamic;

namespace SearchPanel
{
    public class ViewModel
    {
        private DataTable dataTableCollection;

        public ViewModel()
        {
            //Gets the data for DataTable object.
            dataTableCollection = GetGridData();

            //Convert DataTable collection as Dyanamic collection.
            var dynamicCollection = new ObservableCollection<dynamic>();
            foreach (DataRow row in dataTableCollection.Rows)
            {
                dynamic dyn = new ExpandoObject();
                dynamicCollection.Add(dyn);
                foreach (DataColumn column in dataTableCollection.Columns)
                {
                    var dic = (IDictionary<string, object>)dyn;
                    dic[column.ColumnName] = row[column];
                }
            }

            DynamicOrders = dynamicCollection;
        }

        private ObservableCollection<dynamic> _dynamicOrders;

        /// <summary>
        /// Gets or sets the dynamic orders.
        /// </summary>
        /// <value>The dynamic orders.</value>
        public ObservableCollection<dynamic> DynamicOrders
        {
            get
            {
                return _dynamicOrders;
            }
            set
            {
                _dynamicOrders = value;
            }
        }

        public DataTable DataTableCollection
        {
            get { return dataTableCollection; }
            set { dataTableCollection = value; }
        }

        private DataTable GetGridData()
        {
            var myDataTable = new DataTable();

            // Add columns to DataTable.

            myDataTable.Columns.Add("EmployeeID", typeof(int));
            myDataTable.Columns.Add("EmployeeName", typeof(string));
            myDataTable.Columns.Add("Expereience", typeof(double));
            myDataTable.Columns.Add("EmployeeDesignation", typeof(string));
            myDataTable.Columns.Add("CustomerID", typeof(string));
            myDataTable.Columns.Add("ShipCountry", typeof(string));

            // Add some rows to the DataTable.
            myDataTable.Rows.Add(1001, "Sean Jacobson", 0, "Junior Architect", "FRANS", "Argentina");
            myDataTable.Rows.Add(1002, "Phyllis Allen", 0.6, "Team Lead", "MEREP", "Austria");
            myDataTable.Rows.Add(1003, "Marvin Allen", 6, "Team Lead", "MEREP", "Denmark");
            myDataTable.Rows.Add(1004, "Michael Allen", 1.5, "Junior Architect", "SIMOB", "Canada");
            myDataTable.Rows.Add(1005, "Cecil Allison", 3, "Team Lead", "FOLIG", "Mexico");
            myDataTable.Rows.Add(1006, "Tom Johnston", 4, "Senior Architect", "BLONP", "USA");
            myDataTable.Rows.Add(1007, "Thomas Armstrong", 2.1, "Junior Architect", "WELLI", "UK");
            myDataTable.Rows.Add(1008, "John Arthur", 3.3, "Team Lead", "WELLI", "Ireland");
            myDataTable.Rows.Add(1009, "Chris Ashton", 4.2, "Junior Architect", "RISCU", "Denmark");
            myDataTable.Rows.Add(1010, "Teresa Atkinson", 2.2, "Junior Architect", "LINOD", "France");
            myDataTable.Rows.Add(1011, "John Ault", 3.1, "Sales Engineer", "FOLKO", "Argentina");
            myDataTable.Rows.Add(1012, "Robert Avalos", 4.4, "Team Lead", "PICCO", "Austria");
            myDataTable.Rows.Add(1013, "Cecil Allison", 2.1, "Junior Architect", "SIMOB", "Switzerland");
            myDataTable.Rows.Add(1014, "Stephen Ayers", 3.6, "Junior Architect", "MEREP", "Ireland");
            myDataTable.Rows.Add(1015, "Selena Alvarad", 4.6, "Team Lead", "BLONP", "Canada");
            myDataTable.Rows.Add(1016, "Phyllis Allen", 2.1, "Junior Architect", "LINOD", "Mexico");
            myDataTable.Rows.Add(1017, "Maxwell Amland", 3.8, "Senior Architect", "FOLIG", "Austria");
            myDataTable.Rows.Add(1018, "Gustavo Achong", 4, "Engineer", "FRANS", "USA");
            myDataTable.Rows.Add(1019, "Hannah Arakawa", 2.11, "Sales Engineer", "WELLI", "Denmark");
            myDataTable.Rows.Add(1020, "Stephen Ayers", 3.9, "Senior Architect", "SEVES", "Spain");
            myDataTable.Rows.Add(1021, "Mae Anderson", 4.2, "Engineer", "RISCU", "Switzerland");
            myDataTable.Rows.Add(1022, "ames Aguilar", 2.2, "Junior Architect", "SIMOB", "Argentina");
            myDataTable.Rows.Add(1023, "Sean Jacobson", 3.3, "Team Lead", "FURIB", "Canada");
            myDataTable.Rows.Add(1024, "Marvin Allen", 4.4, "Sales Engineer", "FOLKO", "France");
            myDataTable.Rows.Add(1025, "Michael Allen", 2.1, "Junior Architect", "PICCO", "Italy");
            myDataTable.Rows.Add(1026, "Frances Adams", 3.3, "Team Lead", "WARTH", "Germany");
            myDataTable.Rows.Add(1027, "Gustavo Achong", 4.2, "Engineer", "VAFFE", "Argentina");
            myDataTable.Rows.Add(1028, "Chris Ashton", 2.2, "Junior Architect", "FOLIG", "Denmark");
            myDataTable.Rows.Add(1029, "Robert Avalos", 3.3, "Senior Architect", "MEREP", "Canada");
            myDataTable.Rows.Add(1030, "John Arthur", 0, "Sales Engineer", "LINOD", "Austria");
            myDataTable.Rows.Add(1031, "Stephen Ayers", 0, "Junior Architect", "BLONP", "France");
            myDataTable.Rows.Add(1032, "Teresa Atkinson", 3.3, "Team Lead", "RISCU", "Argentina");
            myDataTable.Rows.Add(1033, "Thomas Armstrong", 4.2, "Senior Architect", "FURIB", "Ireland");
            myDataTable.Rows.Add(1034, "Kyley Arbelaez", 0, "Junior Architect", "PICCO", "Austria");
            myDataTable.Rows.Add(1035, "Maxwell Amland", 0, "Senior Architect", "FOLKO", "Denmark");
            myDataTable.Rows.Add(1036, "Frances Adams", 0, "Sales Engineer", "FRANS", "France");
            myDataTable.Rows.Add(1037, "Hannah Arakawa", 2.1, "Sales Engineer", "SIMOB", "Canada");
            myDataTable.Rows.Add(1038, "Kyley Arbelaez", 3.3, "Senior Architect", "FOLIG", "Italy");
            myDataTable.Rows.Add(1039, "Maxwell Amland", 4.2, "Engineer", "SEVES", "Mexico");
            myDataTable.Rows.Add(1040, "Stephen Ayers", 0, "Junior Architect", "LINOD", "Argentina");
            myDataTable.Rows.Add(1041, "John Ault", 0, "Team Lead", "WELLI", "France");
            myDataTable.Rows.Add(1042, "Teresa Atkin0son", 4.4, "Senior Architect", "RISCU", "UK");
            myDataTable.Rows.Add(1043, "Michael Allen", 2.1, "Sales Engineer", "PICCO", "Austria");
            myDataTable.Rows.Add(1044, "Tom Johnston", 3.3, "Team Lead", "BLONP", "Canada");
            myDataTable.Rows.Add(1045, "John Arthur", 4.2, "Engineer", "FOLKO", "Denmark");
            myDataTable.Rows.Add(1046, "Chris Ashton", 0, "Sales Engineer", "SIMOB", "Argentina");
            myDataTable.Rows.Add(1047, "Phyllis Allen", 3.3, "Senior Architect", "FOLIG", "Germany");
            myDataTable.Rows.Add(1048, "Thomas Armstrong", 4.4, "Engineer", "FRANS", "Canada");
            myDataTable.Rows.Add(1049, "Cecil Allison", 3.3, "Senior Architect", "FOLKO", "France");
            myDataTable.Rows.Add(1050, "Sean Jacobson", 4.2, "Engineer", "MEREP", "Austria");
            return myDataTable;
        }
    }
}
